
#ifndef CDLGSETUP_H
#define CDLGSETUP_H

#include <QDialog>
#include <QWidget>
#include <QtDBus>
#include <ui_IDlgSetup.h>

class CDlgSetup : public QDialog, private Ui::IDlgSetup
{
    Q_OBJECT;
        public:
	    CDlgSetup();
            virtual ~CDlgSetup();
	
	private:
	
	private slots:
	    void slotCallSetup();
	    void slotMP3Setup();
            void slotSmsSetup();
            void slotMainSetup();
	    void slotMafwActivate(int status);
	    void slotRTComActivate(int status);
            void slotSmsActivate(int status);

};
#endif
	    
